@@ -4,6 +4,8 @@ from . import compression
 
 import numpy as np
 
+import mapbufferaccel
+
 FORMAT_VERSION = 0
 MAGIC_NUMBERS = b"mapbufr"
 HEADER_LENGTH = 16
@@ -117,34 +119,41 @@ class MapBuffer:
 
     return value  
 
-  def __getitem__(self, label):
+  def find_index_position(self, label):
     index = self.index()
-    N = np.uint64(len(index))
+    N = len(index)
     if N == 0:
       return None
 
-    # Important for speed to ensure all types match
-    # however the numpy type is fickle and keeps
-    # converting itself to a float64 if not everything
-    # is a matching type.
-    label = np.uint64(label)
+    k = mapbufferaccel.eytzinger_binary_search(label, index)
+    if k >= 0 and k < N:
+      return k
 
-    # Cache aware Binary search using eytzinger ordering
-    # not necessarily faster in Python (1.5x slower?), but
-    # leaves the door open for C/C++ implementations.
-    # Since this is a format, if we don't support it from
-    # the start, it'll never happen without headaches.
-    k = np.uint64(1)
-    one = np.uint64(1)
-    while k <= N:
-      k = (k << one) + (index[(k-one),0] < label)
-    k >>= np.uint64(ffs(~k))
-    k -= one
+    return None
 
-    if k < N and label == index[k,0]:
-      return self.getindex(int(k))
+  def get(self, label, *args, **kwargs):
+    pos = self.find_index_position(label)
+    if pos is None: # try to get default argument
+      try:
+        return args[0]
+      except IndexError:
+        try:
+          return kwargs.get("default")
+        except KeyError:
+          raise KeyError("{} was not found.".format(label))
     
-    raise KeyError("{} was not found.".format(label))
+    return self.getindex(pos)
+
+  def __contains__(self, label):
+    pos = self.find_index_position(label)
+    return pos is not None
+
+  def __getitem__(self, label):
+    pos = self.find_index_position(label)
+    if pos is not None:
+      return self.getindex(pos)
+    else:
+      raise KeyError("{} was not found.".format(label))
 
   def dict2buf(self, data, compress=None, tobytesfn=None):
     """Structure [ index length, sorted index, data ]"""
